@@ -64,6 +64,8 @@ def parse_args(args):
                         help='DataFed Upload')
     parser.add_argument('--cells',dest='cells',action='store',default=None,
     help='Number of cyanobacteria and e.coli to initialize simulation with, `e.g., 100,100. ` Default is random number between 1 and 100.')
+    parser.add_argument('--sucR',dest='SucRatio',action='store',default=None,
+                    help='Set sucrose secretion ratio (0 to 10). Default is random.')   
 
     parser.add_argument(
     "-v",
@@ -120,7 +122,8 @@ def main(args):
     _logger.info("Generating NUFEB simulation files")
     # maximum growth rates, mu
     mu_cyanos = round(0.06/3600,7)
-    mu_ecw = 2.7e-04
+    #mu_ecw = 2.7e-04 for 37C only
+    mu_ecw = 6.71e-5
     # molecular weights of co2 and sucrose for unit conversions
     CO2MW = 44.01
     SucMW = 342.3
@@ -130,7 +133,10 @@ def main(args):
         os.mkdir('runs')
     today = str(date.today())
     for n in range(1,int(args.num)+1):
-        SucRatio = round(random.random(),3)
+        if args.SucRatio is not None:
+            SucRatio = float(args.SucRatio)
+        else:
+            SucRatio = round(random.random(),3)
         SucPct = int(SucRatio*100)
         if args.culture_type == 'co':
             cell_types = ['cyano','ecw']
